@@ -19,35 +19,63 @@
 #ifndef __BASICGRAPH_H
 #define __BASICGRAPH_H
 
-#include <QWidget>
+#include <stdio.h>
+
+#include <qglobal.h>
+
+#include <QtWidgets/QWidget>
 #include <QPainter>
 #include <QKeyEvent>
 
+
 #include "ViewWidgetIFace.h"
 #include "BasicOutput.h"
 
+#define GSIZE_INITIAL_WIDTH   300
+#define GSIZE_INITIAL_HEIGHT   300
+
 class BasicGraph : public QWidget, public ViewWidgetIFace
 {
-  Q_OBJECT;
+  Q_OBJECT
  public:
-  BasicGraph(BasicOutput *);
+  BasicGraph();
+  ~BasicGraph();
   QImage *image;
-  QImage *imask;
+  bool initActions(QMenu *, ToolBar *);
+  // used to store current location of mouse
+  // default value of -1 when no mouse recorded over graphic output
+  int mouseX;
+  int mouseY;
+  int mouseB;
+  // used to store location of last mouse click
+  // default value of -1 when no click recorded
+  int clickX;
+  int clickY;
+  int clickB;
+  bool isVisibleGridLines();
 
- 	bool initActions(QMenu *, ToolBar *);
  
  public slots:
-	void slotCopy();
-	void slotPrint();
+  void resize(int, int);
+  void slotGridLines(bool);
+  void slotCopy();
+  void slotPrint();
  
  protected:
   void paintEvent(QPaintEvent *);
   void keyPressEvent(QKeyEvent *);
+  void mousePressEvent(QMouseEvent *);
+  void mouseReleaseEvent(QMouseEvent *);
+  void mouseMoveEvent(QMouseEvent *);
   
  private:
-  uchar imagedata[sizeof(int) * 300 * 300];
-  uchar maskdata[300 * 300];
-  BasicOutput *output;
+  uchar *imagedata;
+  unsigned int gwidth;
+  unsigned int gheight;
+  unsigned int gtop;	// position of image in basicgraph widget
+  unsigned int gleft;
+  bool gridlines;		// show the grid lines or not
+
 };
 
 
