@@ -19,26 +19,29 @@
 #ifndef __BASICOUTPUT_H
 #define __BASICOUTPUT_H
 
-#include <QTextEdit>
 #include <QKeyEvent>
 #include <QPaintEvent>
+#include <QtWidgets/QTextEdit>
+
+#include <qglobal.h>
 
 #include "ViewWidgetIFace.h"
 
 class BasicOutput : public QTextEdit, public ViewWidgetIFace
 {
-  Q_OBJECT;
+  Q_OBJECT
  public:
   BasicOutput();
+  ~BasicOutput();
   
   char *inputString;
   void inputStart();
-  
+
   virtual bool initActions(QMenu *, ToolBar *);
   
  public slots:
   void getInput();
-  void slotPrint(); 
+  void slotPrint();
  
  signals:
   void inputEntered(QString);
@@ -49,6 +52,7 @@ class BasicOutput : public QTextEdit, public ViewWidgetIFace
  private:
   int startPos;
   bool gettingInput;
+  void changeFontSize(unsigned int);
 };
 
 
